#----------------------------------------------------------
#Function for the event procedure
#----------------------------------------------------------
import mwt

def btnop(object):
	#do something...
	object.setProperty("labelString","hello")
	return
mwt.WSGFfunctionRegister("btnop",btnop)
